%define ALD_Ver		1.2.1

Name:         git

License:      GPL
Summary:      Core git tools
Group:        Development/Tools
Version:      1.7.12.4
Release:      0
URL: 		http://kernel.org/pub/software/scm/git/

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/Compiler

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target_  %{nil}
%define target %{_build}

%if 0
%define __os_install_post    \
    %{_rpmconfigdir}/brp-compress \
    %{_rpmconfigdir}/brp-strip %{__strip} \
    %{_rpmconfigdir}/brp-strip-static-archive %{__strip} \
    %{_rpmconfigdir}/brp-strip-shared %{__strip} \
    %{_rpmconfigdir}/brp-strip-comment-note %{__strip} %{__objdump} \
%{nil}
%endif

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}
%define perldir /opt/perl
%define perldir_site %{perldir}/lib/site_perl/5.12.4
%define path_settings prefix=%{_prefix} mandir=%{_mandir} PERLPREFIX=%{perldir} SITEPREFIX=%{perldir} VENDORPREFIX=%{perldir}

# ------------------- description ------------------------------------
%description
Git is a fast, scalable, distributed revision control system with an
unusually rich command set that provides both high-level operations
and full access to internals.

The git rpm installs the core tools with minimal dependencies.
#-------------------------------
%package svn
Summary:        Git tools for importing Subversion repositories
Group:          Development/Tools
Requires:       git = %{version}-%{release}, subversion
%description svn
Git tools for importing Subversion repositories.
#-------------------------------
%package cvs
Summary:        Git tools for importing CVS repositories
Group:          Development/Tools
Requires:       git = %{version}-%{release}, cvs, cvsps
%description cvs
Git tools for importing CVS repositories.
#-------------------------------
%package arch
Summary:        Git tools for importing Arch repositories
Group:          Development/Tools
Requires:       git = %{version}-%{release}, tla
%description arch
Git tools for importing Arch repositories.
#-------------------------------
%package email
Summary:        Git tools for sending email
Group:          Development/Tools
Requires:	git = %{version}-%{release}
%description email
Git tools for sending email.
#-------------------------------
%package gitweb
Summary:	Git web interface
Group:          Development/Tools
Requires:       git = %{version}-%{release}
%description gitweb
Browsing git repository on the web
#-------------------------------
%package perl
Summary:      Perl interface to Git
Group:        Development/Libraries
Requires:       git = %{version}-%{release}
#Requires:       perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
%description perl
Perl interface to Git
#-------------------------------
%package perl-man3
Summary:      man3 for Perl
Group:        Documentation
%description perl-man3
man3 for Perl
#-------------------------------
%package doc
Summary:      Doc for %{name}
Group:        Documentation
%description doc
Doc for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%ifarch %{ix86}
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%ifarch x86_64
OPTFLAGS="-Os -fno-asynchronous-unwind-tables"
%endif
%ifarch %{arm}
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections"
LDFLAGS="-Wl,--gc-sections"

%if %{_CROSS}
export ac_cv_fread_reads_directories="no"
export ac_cv_snprintf_returns_bogus="no"
%endif

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--without-libpcre \
	--without-iconv \
	--without-python \
	--without-tcltk \
	&>FConfigure_log.txt

make %{path_settings} V=1 &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}
mkdir -p $RPM_BUILD_ROOT/etc/gitattributes
mkdir -p $RPM_BUILD_ROOT/etc/gitconfig

export NO_INSTALL_HARDLINKS="y"
make DESTDIR="$RPM_BUILD_ROOT" %{path_settings} install &>FInstall_log.txt

find $RPM_BUILD_ROOT -type f -name .packlist -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type f -name '*.bs' -empty -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type f -name perllocal.pod -exec rm -f {} ';'

rm -rf $RPM_BUILD_ROOT%{_datadir}/locale
#rm -rf $RPM_BUILD_ROOT%{_prefix}/man
mv $RPM_BUILD_ROOT%{perldir}/share/man $RPM_BUILD_ROOT%{perldir}/man
cp COPYING README $RPM_BUILD_ROOT%{docdir}/


%if %{_CROSS}
%if %{_lib} != "lib"
if test -d $RPM_BUILD_ROOT%{_prefix}/lib/vendor_perl; then
mv $RPM_BUILD_ROOT%{_prefix}/lib/vendor_perl $RPM_BUILD_ROOT%{_libdir}/
fi
%endif
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

cp Documentation/*.txt $RPM_BUILD_ROOT%{docdir}/

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-svn-$SE $DD/%{name}-svn-$DE
  mv %{name}-cvs-$SE $DD/%{name}-cvs-$DE
  mv %{name}-arch-$SE $DD/%{name}-arch-$DE
  mv %{name}-email-$SE $DD/%{name}-email-$DE
  mv %{name}-gitweb-$SE $DD/%{name}-gitweb-$DE
  mv %{name}-perl-$SE $DD/%{name}-perl-$DE
  mv %{name}-perl-man3-$SE $DD/%{name}-perl-man3-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r etc usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%Files
/etc/gitattributes
/etc/gitconfig
%{_bindir}/git
%{_bindir}/git-receive-pack
%{_bindir}/git-upload-archive
%{_bindir}/git-upload-pack
%{_bindir}/git-shell
%exclude %{_libexecdir}/git-core/git-add--interactive
%exclude %{_libexecdir}/git-core/git-archimport
%exclude %{_libexecdir}/git-core/git-difftool
%exclude %{_libexecdir}/git-core/git-svn
%exclude %{_libexecdir}/git-core/git-cvs*
%exclude %{_libexecdir}/git-core/git-send-email
%{_libexecdir}/git-core
%{_datadir}/git-core
%{docdir}/COPYING
%{docdir}/README
%{docdir}/config.txt
%{docdir}/user-manual.txt

%Files svn
%{perldir_site}/Git
%{_libexecdir}/git-core/git-svn

%Files cvs
%{_bindir}/git-cvsserver
%{_libexecdir}/git-core/git-cvs*

%Files arch
%{_libexecdir}/git-core/git-archimport

%Files email
%{_libexecdir}/git-core/git-send-email

%Files gitweb
%{_datadir}/gitweb

%Files perl
%{_libexecdir}/git-core/git-difftool
%{_libexecdir}/git-core/git-add--interactive
%{perldir_site}/Error.pm
%{perldir_site}/Git.pm

%Files perl-man3
%{perldir}/man

%Files doc
%exclude %{docdir}/config.txt
%exclude %{docdir}/user-manual.txt
%{docdir}/*.txt
